@@ -1,4 +1,4 @@
-from tyba_client.models import PVModelTypes, PVStorageModel, StandaloneStorageModel
+from tyba_client.models import PVModel, PVStorageModel, StandaloneStorageModel
 import requests
 from urllib.parse import urljoin
 
@@ -22,7 +22,7 @@ class Client(object):
     def _base_url(self):
         return self.host + "/public/" + self.DEFAULT_OPTIONS["version"] + "/"
 
-    def schedule_pv(self, pv_model: PVModelTypes):
+    def schedule_pv(self, pv_model: PVModel):
         model_json_dict = pv_model.to_dict()
         url = urljoin(self._base_url(), "schedule-pv")
         return requests.post(url,
